"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mochaTestServer = exports.startTestServer = void 0;
const mongodb_runner_1 = require("mongodb-runner");
const crypto_1 = require("crypto");
const path_1 = __importDefault(require("path"));
const os_1 = __importDefault(require("os"));
function hash(input) {
    return (0, crypto_1.createHash)('sha256').update(input).digest('hex').slice(0, 12);
}
let isClosed = false;
const clusters = new Map();
const defaults = {
    topology: 'standalone',
    tmpDir: path_1.default.join(os_1.default.tmpdir(), `compass-tests-${hash(process.env.EVERGREEN_TASK_ID ?? '')}`),
    logDir: process.env.MONGODB_RUNNER_LOGDIR,
    version: process.env.MONGODB_VERSION,
};
async function startTestServer(config = {}) {
    const key = JSON.stringify(config);
    const existing = !config.alwaysStartNewServer && clusters.get(key);
    if (existing && !existing.isClosed())
        return existing;
    const cluster = await mongodb_runner_1.MongoCluster.start({
        ...defaults,
        ...config,
    });
    if (isClosed) {
        await cluster.close();
        throw new Error('Cluster started while mocha tests were finishing');
    }
    clusters.set(key, cluster);
    return cluster;
}
exports.startTestServer = startTestServer;
function mochaTestServer(...args) {
    let cluster;
    before(async function () {
        this.timeout(500000);
        cluster = await startTestServer(...args);
    });
    after(async function () {
        await cluster?.close();
        cluster = undefined;
    });
    return () => {
        if (!cluster)
            throw new Error('before() hook not ran yet');
        return cluster;
    };
}
exports.mochaTestServer = mochaTestServer;
if (typeof globalThis.after === 'function') {
    after(async function () {
        isClosed = true;
        const toClose = [...clusters.values()];
        clusters.clear();
        await Promise.all(toClose.map((cluster) => cluster.close()));
    });
}
//# sourceMappingURL=index.js.map